==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/synapse/kotlin/inputs/PurviewConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.synapse.kotlin.inputs

import com.pulumi.azurenative.synapse.inputs.PurviewConfigurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Purview Configuration
 * @property purviewResourceId Purview Resource ID
 */
public data class PurviewConfigurationArgs(
    public val purviewResourceId: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.synapse.inputs.PurviewConfigurationArgs> {
    override fun toJava(): com.pulumi.azurenative.synapse.inputs.PurviewConfigurationArgs =
        com.pulumi.azurenative.synapse.inputs.PurviewConfigurationArgs.builder()
            .purviewResourceId(purviewResourceId?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [PurviewConfigurationArgs].
 */
@PulumiTagMarker
public class PurviewConfigurationArgsBuilder internal constructor() {
    private var purviewResourceId: Output<String>? = null

    /**
     * @param value Purview Resource ID
     */
    @JvmName("vugxjwvksvqngbxu")
    public suspend fun purviewResourceId(`value`: Output<String>) {
        this.purviewResourceId = value
    }

    /**
     * @param value Purview Resource ID
     */
    @JvmName("qwmvlsffkmswqrgv")
    public suspend fun purviewResourceId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.purviewResourceId = mapped
    }

    internal fun build(): PurviewConfigurationArgs = PurviewConfigurationArgs(
        purviewResourceId = purviewResourceId,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/synapse/kotlin/inputs/PurviewConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.synapse.kotlin.inputs

import com.pulumi.azurenative.synapse.inputs.PurviewConfigurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Purview Configuration
 * @property purviewResourceId Purview Resource ID
 */
public data class PurviewConfigurationArgs(
    public val purviewResourceId: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.synapse.inputs.PurviewConfigurationArgs> {
    override fun toJava(): com.pulumi.azurenative.synapse.inputs.PurviewConfigurationArgs =
        com.pulumi.azurenative.synapse.inputs.PurviewConfigurationArgs.builder()
            .purviewResourceId(purviewResourceId?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [PurviewConfigurationArgs].
 */
@PulumiTagMarker
public class PurviewConfigurationArgsBuilder internal constructor() {
    private var purviewResourceId: Output<String>? = null

    /**
     * @param value Purview Resource ID
     */
    @JvmName("rackevbbtovmqfdu")
    public suspend fun purviewResourceId(`value`: Output<String>) {
        this.purviewResourceId = value
    }

    /**
     * @param value Purview Resource ID
     */
    @JvmName("pgaluxikhchnhvjj")
    public suspend fun purviewResourceId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.purviewResourceId = mapped
    }

    internal fun build(): PurviewConfigurationArgs = PurviewConfigurationArgs(
        purviewResourceId = purviewResourceId,
    )
}
